<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Auth\LoginRequest;
use App\Http\Requests\Auth\RegisterRequest;
use App\Http\Requests\Auth\UpdatePasswordRequest;
use App\Http\Resources\UserResource;
use App\Mail\ForgetPasswordMail;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;

class AuthController extends Controller
{
    public function register(RegisterRequest $request) {
        $newUser = User::query()->create($request->all());
        $token = $newUser->createToken("app_token")->plainTextToken;

        return response([
            "user" => $newUser,
            'token' => $token
        ], 201);
    }

    public function login(LoginRequest $request) {
        $user = User::query()->where("email", $request->email)->first();

        if (!$user || !Hash::check($request->password, $user->password)) {
            return response(["message" => "Bad credentials"], 401);
        }

        if (isset($user->frenchise_id) && !$user->frenchise->is_active) {
            return response(["message" => "Franchise is not active"], 422);
        }

        $token = $user->createToken("app_token")->plainTextToken;

        return ["data" => new UserResource($user), "token" => $token];
    }

    public function logout() {
        auth()->user()->tokens()->delete();
        return response(['message' => 'Logged out successfully']);
    }

    public function forgetPassword(Request $request) {
        $request->validate([
            "email" => "required|string|email"
        ]);

        $user = User::query()->where("email", $request->email)->first();

        if (!isset($user)) {
            return response([
                "status" => "failed",
                "status_message" => "User not found",
            ], 404);
        }

        $user->forget_password_token = Str::random(32);
        Mail::to($user->email)->send(new ForgetPasswordMail($user));
        $user->save();

        return response([
            "status" => "success",
            "status_message" => "Password reset link has been sent to your registered email id. Click on it to reset your password."
        ]);
    }

    public function updatePassword(UpdatePasswordRequest $request) {
        $user = User::query()->where("forget_password_token", $request->token)->first();

        if (!isset($user)) {
            return response(["error" => "User does not exists or token expired!"], 422);
        }

        $user->password = $request->password;
        $user->save();

        return response(["success" => 'Password changed successfully!']);
    }
}
