<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\BillDetailResource;
use App\Models\BillDetail;
use Illuminate\Http\Request;

class BillDetailController extends Controller
{
    public function index() {
        $billDetails = $this->paginateOrGet(
            BillDetail::query()->latest());

        return BillDetailResource::collection($billDetails);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'user_id' => ['required', 'exists:users'],
            'bill_id' => ['required', 'exists:bills'],
            'recipe_id' => ['required', 'exists:recipes'],
            'qty' => ['nullable'],
            'price' => ['nullable', 'integer'],
            'total_amount' => ['nullable', 'integer'],
        ]);

        return new BillDetailResource(BillDetail::create($data));
    }

    public function show(BillDetail $billDetail) {
        return new BillDetailResource($billDetail);
    }

    public function update(Request $request, BillDetail $billDetail) {
        $data = $request->validate([
            'user_id' => ['required', 'exists:users'],
            'bill_id' => ['required', 'exists:bills'],
            'recipe_id' => ['required', 'exists:recipes'],
            'qty' => ['nullable'],
            'price' => ['nullable', 'integer'],
            'total_amount' => ['nullable', 'integer'],
        ]);

        $billDetail->update($data);

        return new BillDetailResource($billDetail);
    }

    public function destroy(BillDetail $billDetail) {
        $billDetail->delete();

        return response()->json();
    }
}
