<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\ExpenseResource;
use App\Models\Expense;
use Illuminate\Http\Request;

class ExpenseController extends Controller
{
    public function index() {
        $expenses = $this->paginateOrGet(
            Expense::with(["franchise", "expenseType"])->filter()->latest());

        return ExpenseResource::collection($expenses);
    }

    public function store(Request $request) {
        $request->validate([
            'expense_type_id' => ['required', "string"],
            'franchise_id' => ['required', "string"],
            'name' => ['required', "string"],
            'amount' => ['required', "string"],
        ]);

        return response()->json(
            new ExpenseResource(Expense::create($request->all())), 201
        );
    }

    public function show(Expense $expense) {
        return new ExpenseResource($expense->loadMissing(["franchise", "expenseType"]));
    }

    public function update(Request $request, Expense $expense) {
        $request->validate([
            'expense_type_id' => ['sometimes'],
            'franchise_id' => ['sometimes'],
            'name' => ['sometimes'],
            'amount' => ['sometimes'],
        ]);

        $expense->update($request->all());

        return new ExpenseResource($expense);
    }

    public function destroy(Expense $expense) {
        $expense->delete();
        return response()->json(["message" => "Expense deleted successfully!"]);
    }
}
