<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\ExpenseTypeResource;
use App\Models\ExpenseType;
use Illuminate\Http\Request;

class ExpenseTypeController extends Controller
{
    public function index() {
        $expenseTypes = $this->paginateOrGet(ExpenseType::with(["franchise", "expenses"])
            ->filter()->latest());

        return ExpenseTypeResource::collection($expenseTypes);
    }

    public function store(Request $request) {
        $request->validate([
            'franchise_id' => ['required', 'string'],
            'name' => ['required', 'string'],
        ]);

        return new ExpenseTypeResource(ExpenseType::create($request->all()));
    }

    public function show(ExpenseType $expenseType) {
        return new ExpenseTypeResource(
            $expenseType->loadMissing(["franchise", "expenses"])
        );
    }

    public function update(Request $request, ExpenseType $expenseType) {
        $request->validate([
            'franchise_id' => ['sometimes', 'string'],
            'name' => ['sometimes', 'string'],
        ]);

        $expenseType->update($request->all());

        return new ExpenseTypeResource($expenseType);
    }

    public function destroy(ExpenseType $expenseType) {
        $expenseType->delete();

        return response()->json(["message", "Expense type deleted successfully!"]);
    }
}
