<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\PaymentTypeResource;
use App\Models\PaymentType;
use Illuminate\Http\Request;

class PaymentTypeController extends Controller
{
    public function index() {
        $paymentTypes = $this->paginateOrGet(PaymentType::with("franchise")
            ->filter()->latest());

        return PaymentTypeResource::collection($paymentTypes);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'franchise_id' => ['required', "string"],
            'payment_type' => ['required', 'string'],
        ]);

        return new PaymentTypeResource(PaymentType::create($data));
    }

    public function show(PaymentType $paymentType) {
        return new PaymentTypeResource($paymentType->loadMissing("franchise"));
    }

    public function update(Request $request, PaymentType $paymentType) {
        $data = $request->validate([
            'franchise_id' => ['sometimes', "string"],
            'payment_type' => ['sometimes', 'string'],
        ]);

        $paymentType->update($data);

        return new PaymentTypeResource($paymentType);
    }

    public function destroy(PaymentType $paymentType) {
        $paymentType->delete();

        return response()->json(["message" => "Payment type deleted successfully!"]);
    }
}
