<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\PurchaseOrderDetailResource;
use App\Models\PurchaseOrderDetail;
use Illuminate\Http\Request;

class PurchaseOrderDetailController extends Controller
{
    public function index() {
        $purchaseOrderDetails = $this->paginateOrGet(PurchaseOrderDetail::query()->latest());

        return PurchaseOrderDetailResource::collection($purchaseOrderDetails);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'purchase_order_id' => ['nullable', 'exists:purchase_orders'],
            'item_id' => ['nullable', 'exists:items'],
            'qty' => ['nullable'],
            'price' => ['nullable'],
        ]);

        return new PurchaseOrderDetailResource(PurchaseOrderDetail::create($data));
    }

    public function show(PurchaseOrderDetail $purchaseOrderDetail) {
        return new PurchaseOrderDetailResource($purchaseOrderDetail);
    }

    public function update(Request $request, PurchaseOrderDetail $purchaseOrderDetail) {
        $data = $request->validate([
            'purchase_order_id' => ['nullable', 'exists:purchase_orders'],
            'item_id' => ['nullable', 'exists:items'],
            'qty' => ['nullable'],
            'price' => ['nullable'],
        ]);

        $purchaseOrderDetail->update($data);

        return new PurchaseOrderDetailResource($purchaseOrderDetail);
    }

    public function destroy(PurchaseOrderDetail $purchaseOrderDetail) {
        $purchaseOrderDetail->delete();

        return response()->json();
    }
}
