<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\RecipeDetailResource;
use App\Models\RecipeDetail;
use Illuminate\Http\Request;

class RecipeDetailController extends Controller
{
    public function index() {
        $recipeDetails = $this->paginateOrGet(RecipeDetail::query()->latest());

        return RecipeDetailResource::collection($recipeDetails);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'recipe_id' => ['required', 'exists:recipes'],
            'item_id' => ['required', 'exists:items'],
            'qty' => ['required'],
        ]);

        return new RecipeDetailResource(RecipeDetail::create($data));
    }

    public function show(RecipeDetail $recipeDetail) {
        return new RecipeDetailResource($recipeDetail);
    }

    public function update(Request $request, RecipeDetail $recipeDetail) {
        $data = $request->validate([
            'recipe_id' => ['required', 'exists:recipes'],
            'item_id' => ['required', 'exists:items'],
            'qty' => ['required'],
        ]);

        $recipeDetail->update($data);

        return new RecipeDetailResource($recipeDetail);
    }

    public function destroy(RecipeDetail $recipeDetail) {
        $recipeDetail->delete();

        return response()->json();
    }
}
