<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\SupportResource;
use App\Models\Support;
use Illuminate\Http\Request;

class SupportController extends Controller
{
    public function index() {
        $supports = $this->paginateOrGet(Support::query()->latest());

        return SupportResource::collection($supports);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'subject' => ['nullable'],
            'remarks' => ['nullable'],
            'image' => ['nullable'],
            'user_id' => ['nullable', 'exists:users'],
        ]);

        return new SupportResource(Support::create($data));
    }

    public function show(Support $support) {
        return new SupportResource($support);
    }

    public function update(Request $request, Support $support) {
        $data = $request->validate([
            'subject' => ['nullable'],
            'remarks' => ['nullable'],
            'image' => ['nullable'],
            'user_id' => ['nullable', 'exists:users'],
        ]);

        $support->update($data);

        return new SupportResource($support);
    }

    public function destroy(Support $support) {
        $support->delete();

        return response()->json();
    }
}
