<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\TicketReplyResource;
use App\Http\Traits\HasStoreFile;
use App\Models\TicketReply;
use Illuminate\Http\Request;

class TicketReplyController extends Controller
{
    use HasStoreFile;

    public function index() {
        $ticketReplies = $this->paginateOrGet(
            TicketReply::query()->latest());

        return TicketReplyResource::collection($ticketReplies);
    }

    public function store(Request $request) {
        $data = $request->validate([
            'user_id' => ['required', 'exists:users,id'],
            'ticket_id' => ['required', 'exists:tickets,id'],
            'reply' => ['required'],
            'file' => ['sometimes', "file", "mimes:jpg,jpeg,png,pdf", "max:2048"],
        ]);

        $ticketReply = new TicketReply($data);
        if ($request->hasFile("file")) {
            $ticketReply->file = $this->storeFile($request, "file", "ticket-replies");
        }
        $ticketReply->save();

        return new TicketReplyResource($ticketReply);
    }

    public function show(TicketReply $ticketReply) {
        return new TicketReplyResource($ticketReply->loadMissing(["user", "ticket"]));
    }

    public function update(Request $request, TicketReply $ticketReply) {
        $data = $request->validate([
            'user_id' => ['sometimes', 'exists:users,id'],
            'ticket_id' => ['sometimes', 'exists:tickets,id'],
            'reply' => ['required'],
            'file' => $request->hasFile("file")
                ? ["sometimes", "file", "mimes:jpg,jpeg,png,pdf", "max:2048"]
                : ["nullable", "string"],
        ]);

        if ($request->hasFile("file")) {
            $this->deleteFile("ticket-replies", $ticketReply->file);
            $data["file"] = $this->storeFile($request, "file", "ticket-replies");
        }

        $ticketReply->update($data);

        return new TicketReplyResource($ticketReply);
    }

    public function destroy(TicketReply $ticketReply) {
        $this->deleteFile("ticket-replies", $ticketReply->file);
        $ticketReply->delete();

        return response()->json();
    }
}
